#!/usr/bin/env Rscript

library(readr)
library(dplyr, warn.conflicts = FALSE)
library(httr)

args <- commandArgs(trailingOnly = TRUE)
user     <- args[[1]]
token    <- args[[2]]
version  <- args[[3]]
tbl_name <- args[[4]]

# load download links
tbl_download_links <- read_csv(
    "config/tbl_download_links.csv",
    col_types = c(
        col_character(),
        col_character(),
        col_character()
    )
)

# check uniqueness
tbl_download_links %>%
    group_by(version, tbl_name) %>%
    {
        if (n_groups(.) < nrow(.))
            stop("download links not unique, check file")
    }

# extract link for query
tbl_download_link <- tbl_download_links %>%
    filter(
        version  == get("version", envir = .GlobalEnv),
        tbl_name == get("tbl_name", envir = .GlobalEnv)
    ) %>%
    pull(download_link)

if (length(tbl_download_link) == 0)
    stop("no neurobot download link for table 'tbl_%s.csv' version '%s' found", tbl_name, version)

# download csv file via neurobot api call
res <- GET(
    sprintf("https://neurobot-stage.incf.org/api/data/%s.csv", tbl_download_link),
    authenticate(user, token, type = "digest")
)

# check for success and save
if (res$status_code != 200)
    stop(sprintf("error downloading tbl_%s.csv, http status code: %s", tbl_name, res$status_code))

writeBin(content(res, "raw"), sprintf("tbl_%s.csv", tbl_name))
